@@ -1,6 +1,6 @@
 import sys
 sys.path.append("..")
-from ..loginms import login as login_acc
+from .loginms import login as login_acc
 import aiohttp
 import datetime
 import requests
